@@ -18,6 +18,7 @@ __all__ = [
     "StitchVideosOp",
     "QueryDatabaseOutputDataOp",
     "QueryDatabaseOutputStringOp",
+    "VideoInDatabaseOp",
 ]
 
 AddPyOp = load_component_from_file(
@@ -57,3 +58,7 @@ QueryDatabaseOutputStringOp = load_component_from_file(
         os.path.dirname(__file__), "query_database_output_string/component.yaml"
     )
 )
+
+VideoInDatabaseOp = load_component_from_file(
+    os.path.join(os.path.dirname(__file__), "video_in_database/component.yaml")
+)
